@@ -22,6 +22,26 @@ class DynamicRoleSecurityManagerMixin:
             self.authoauthview = DynamicRoleAuthOAuthView
 
 
+def azure_oauth_user_info(provider, resp, parser):
+    log.info("Azure response received : {0}".format(resp))
+
+    id_token = resp["id_token"]
+    log.info(str(id_token))
+    me = parser(id_token)
+    log.info("Parse JWT token : {0}".format(me))
+
+    # must set username as email for migration from OIDC to OAuth
+    return {
+        "name": me.get("name", ""),
+        "email": me["email"],
+        "first_name": me.get("given_name", ""),
+        "last_name": me.get("family_name", ""),
+        "id": me["oid"],
+        "username": me["email"],
+        "roles": me.get("roles", []),
+    }
+
+
 try:
     from superset.security import SupersetSecurityManager
     class SupersetOIDCSecurityManager(DynamicRoleSecurityManagerMixin,
@@ -39,48 +59,40 @@ try:
             if provider != 'azure':
                 return super().get_oauth_user_info(provider, resp)
 
-            log.error("message from fab_auth_dynamic_roles")
-            log.error("Azure response received : {0}".format(resp))
-            id_token = resp["id_token"]
-            log.error(str(id_token))
-            me = self._azure_jwt_token_parse(id_token)
-            log.error("Parse JWT token : {0}".format(me))
-            # must set username from email and email from email for migration from OIDC to OAuth
-            return {
-                "name": me.get("name", ""),
-                "email": me["email"],
-                "first_name": me.get("given_name", ""),
-                "last_name": me.get("family_name", ""),
-                "id": me["oid"],
-                "username": me["email"],
-                "roles": me.get("roles", []),
-            }
+            return azure_oauth_user_info(provider, resp, self._azure_jwt_token_parse)
 
 except ImportError:
-    log.error("from superset.security import SupersetSecurityManager failed")
+    log.warning("from superset.security import SupersetSecurityManager failed")
 
 
+exist_airflow = False
+
 try:
-    from airflow.www_rbac.security import AirflowSecurityManager
+    from airflow.www.security import AirflowSecurityManager
+    exist_airflow = True
+
+except ImportError:
+    try:
+        from airflow.www_rbac.security import AirflowSecurityManager
+        exist_airflow = True
+    except ImportError:
+        log.warning("from airflow.www_rbac.security import AirflowSecurityManager failed")
+
+
+if exist_airflow:
     class AirflowOIDCSecurityManager(DynamicRoleSecurityManagerMixin,
                                      AirflowSecurityManager):
         pass
     class AirflowOAuthSecurityManager(DynamicRoleSecurityManagerMixin,
                                       AirflowSecurityManager):
-        pass
+        def __init__(self, appbuilder):
+            super().__init__(appbuilder)
+            if self.auth_type == AUTH_OAUTH:
+                self.oauth_user_info = self.get_oauth_user_info
 
-except ImportError:
-    log.error("from airflow.www_rbac.security import AirflowSecurityManager failed")
+        def get_oauth_user_info(self, provider, resp):
+            if provider != 'azure':
+                return super().get_oauth_user_info(provider, resp)
 
+            return azure_oauth_user_info(provider, resp, self._azure_jwt_token_parse)
 
-try:
-    from astronomer.flask_appbuilder.security import AirflowAstroSecurityManager
-    class AirflowAstroOIDCSecurityManager(DynamicRoleSecurityManagerMixin,
-                                          AirflowAstroSecurityManager):
-        pass
-    class AirflowAstroOAuthSecurityManager(DynamicRoleSecurityManagerMixin,
-                                          AirflowAstroSecurityManager):
-        pass
-
-except ImportError:
-    log.error("from astronomer.flask_appbuilder.security import AirflowAstroSecurityManager failed")
